@@ -31,9 +31,32 @@
 #define AGS_FUNCTIONAL_TEST_UTIL_MACHINE_PROPERTIES_BULK_INPUT_TAB (3)
 #define AGS_FUNCTIONAL_TEST_UTIL_MACHINE_PROPERTIES_RESIZE_TAB (4)
 
+#define AGS_FUNCTIONAL_TEST_UTIL_IDLE_CONDITION(f) ((AgsFunctionalTestUtilIdleCondition)(f))
+
+typedef struct _AgsFunctionalTestUtilContainerTest AgsFunctionalTestUtilContainerTest;
+
+typedef gboolean (*AgsFunctionalTestUtilIdleCondition)(gpointer data);
+
+struct _AgsFunctionalTestUtilContainerTest
+{
+  GtkContainer **container;
+
+  guint count;
+};
+
 void ags_functional_test_util_setup_and_launch();
 void ags_functional_test_util_setup_and_launch_filename(gchar *filename);
+void ags_functional_test_util_reaction_time();
+void ags_functional_test_util_reaction_time_long();
 void ags_functional_test_util_idle();
+void ags_functional_test_util_idle_condition_and_timeout(AgsFunctionalTestUtilIdleCondition idle_condition,
+							 struct timespec *timeout,
+							 gpointer data);
+
+gboolean ags_functional_test_util_idle_test_widget_visible(GtkWidget **widget);
+gboolean ags_functional_test_util_idle_test_widget_hidden(GtkWidget **widget);
+gboolean ags_functional_test_util_idle_test_container_children_count(AgsFunctionalTestUtilContainerTest *container_test);
+gboolean ags_functional_test_util_idle_test_null(GtkWidget **widget);
 
 GtkMenu* ags_functional_test_util_submenu_find(GtkMenu *menu,
 					       gchar *item_label);
@@ -209,8 +232,11 @@ gboolean ags_functional_test_util_machine_rename_close(guint nth_machine);
 gboolean ags_functional_test_util_machine_rename_set_name(guint nth_machine,
 							  gchar *name);
 
+GtkWidget* ags_functional_test_util_get_line_editor(GtkWidget *machine_editor,
+						    guint nth_pad, guint nth_audio_channel,
+						    gboolean is_output);
+
 gboolean ags_functional_test_util_machine_properties_open(guint nth_machine);
-gboolean ags_functional_test_util_machine_properties_close(guint nth_machine);
 
 gboolean ags_functional_test_util_machine_properties_click_tab(guint nth_machine,
 							       guint nth_tab);
@@ -226,7 +252,7 @@ gboolean ags_functional_test_util_machine_properties_effect_add(guint nth_machin
 								guint pad, guint audio_channel);
 gboolean ags_functional_test_util_machine_properties_effect_remove(guint nth_machine,
 								   guint pad, guint audio_channel,
-								   guint nth);
+								   guint nth_effect);
 
 gboolean ags_functional_test_util_machine_properties_effect_plugin_type(guint nth_machine,
 									guint pad, guint audio_channel,
